@@ -1,14 +1,30 @@
 import json
 import re
 from rich.prompt import Prompt
+from pathlib import Path
 
-def get_runtime_settings(filename:str = "haws/config/runtime.json"):
+root_dir = str(Path(__file__).parent.parent.absolute())
+runtime = root_dir + '/config/runtime.json'
 
-    with open(filename,'r') as fh:
+
+def get_runtime_settings(filename: str = runtime):
+
+    with open(filename, 'r') as fh:
         settings = json.load(fh)
 
     return settings
 
+
+def update_runtime_settings(data: dict, filename: str = runtime):
+    current_settings = get_runtime_settings(filename=filename)
+
+    for key, value in data.items():
+        current_settings[key] = value
+
+    with open(runtime, 'w') as fh:
+        json.dump(export, fh, indent=4)
+
+
 def setup_cli():
     aws_id = Prompt.ask("[blue bold]Your AWS ID: [/blue bold]")
     aws_key = key = Prompt.ask(
@@ -26,5 +42,5 @@ def setup_cli():
         'lx_apitoken': lx_apitoken
     }
 
-    with open('haws/config/runtime.json', 'w') as fh:
+    with open(runtime, 'w') as fh:
         json.dump(export, fh, indent=4)
